## 基金数据

在Tushare Pro基金数据模块里面，我们打算上线公募基金和私募基金两部分数据，数据来源于网络公开渠道和第三方合作伙伴。当前阶段，我们先上线部分公募基金数据，包括了基金基础信息,基金净值,基金分红等常规数据。未来将逐步丰富数据内容,同时进一步加强数据的稳定性与可靠性。

- 公募基金列表
- 公募基金公司
- 公募基金净值
- 场内基金日线行情
- 公募基金分红
- 公募基金持仓数据